pygeodesy.rhumb.solve.RhumbLineSolve

Package pygeodesy :: Package rhumb :: Module solve :: Class RhumbLineSolve |
[frames] | no frames]

# Class RhumbLineSolve

      object --+
               |
    named._Named --+
                   |
    named._NamedBase --+
                       |
        karney._CapsBase --+
                           |
    solveBase._SolveCapsBase --+
                               |
            solveBase._SolveBase --+
                                   |
               solveBase._Solve3Base --+
                                       |
               solveBase._SolveGDictBase --+
                                           |
                             _RhumbSolveBase --+
                                               |
      object --+                               |
               |                               |
    named._Named --+                           |
                   |                           |
    named._NamedBase --+                       |
                       |                       |
        karney._CapsBase --+                   |
                           |                   |
    solveBase._SolveCapsBase --+               |
                               |               |
            solveBase._SolveBase --+           |
                                   |           |
               solveBase._Solve3Base --+       |
                                       |       |
               solveBase._SolveGDictBase --+   |
                                           |   |
               solveBase._SolveGDictLineBase --+
                                               |
                                              RhumbLineSolve

Wrapper to invoke Karney's RhumbSolve like a class, similar to pygeodesy.RhumbLine and pygeodesy.RhumbLineAux.

Notes:

- Use property `RhumbSolve` or env variable `PYGEODESY_RHUMBSOLVE` to specify the (fully qualified) path to the `RhumbSolve` executable.
- This `rhumb line` is intended for testing purposes only, it invokes the `RhumbSolve` executable for every method call.

Instance Methods
__init__(self, rhumb, lat1, lon1, azi12, caps=1929, **name) New RhumbLineSolve instance, allowing points to be found along a rhumb starting at `(lat1, lon1)` with azimuth `azi12`. |
Position(self, s12, **unused) Find the position on the line given `s12`. |
toStr(self, **prec_sep_other) Return this `RhumbLineSolve` as string. |
Inherited from `solveBase._SolveGDictBase`: `ArcDirect`, `Direct`, `Inverse`, `Inverse1` Inherited from `solveBase._SolveCapsBase`: `invokat`, `invoke`, `linelimit` Inherited from `karney._CapsBase`: `caps_` Inherited from `named._NamedBase`: `__repr__`, `__str__`, `others`, `toRepr` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Variables
Inherited from `karney._CapsBase`: `ALL`, `AREA`, `AZIMUTH`, `DISTANCE`, `DISTANCE_IN`, `EMPTY`, `GEODESICSCALE`, `LATITUDE`, `LINE_CAPS`, `LINE_OFF`, `LONGITUDE`, `LONG_UNROLL`, `NONFINITONAN`, `REDUCEDLENGTH`, `STANDARD`, `STANDARD_LINE`

Properties
| azi12 Get this rhumb line's azimuth (compass `degrees`).
| azi1 Get this rhumb line's azimuth (compass `degrees`).
| azi12_sincos2 Get the sine and cosine of this rhumb line's azimuth (2-tuple `(sin, cos)`).
| azi1_sincos2 Get the sine and cosine of this rhumb line's azimuth (2-tuple `(sin, cos)`).
Inherited from `_RhumbSolveBase`: `RhumbSolve` Inherited from `solveBase._SolveGDictLineBase`: `datum`, `ellipsoid`, `lat1`, `lon1` Inherited from `solveBase._SolveBase`: `reverse2`, `unroll` Inherited from `solveBase._SolveCapsBase`: `Exact`, `a`, `b`, `f`, `flattening`, `invokation`, `prec`, `status`, `verbose`, `version` Inherited from `karney._CapsBase`: `caps`, `debug` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, rhumb, lat1, lon1, azi12, caps=1929, **name) (Constructor) |
New RhumbLineSolve instance, allowing points to be found along a rhumb starting at `(lat1, lon1)` with azimuth `azi12`. Arguments: `rhumb` - The rhumb to use (RhumbSolve). `lat1` - Latitude of the first point (`degrees90`). `lon1` - Longitude of the first point (`degrees180`). `azi12` - Azimuth of the rhumb line (compass `degrees180`). `caps` - Bit-or'ed combination of Caps values specifying the capabilities the RhumbLineSolve instance should possess, always `Caps.ALL`. Include `Caps.LINE_OFF` if updates to the `rhumb` should not be reflected in this RhumbLineSolve instance. `name` - Optional `name=NN` (`str`). `name` - Optional name (`str`). Raises: `RhumbError` - Invalid path for `RhumbSolve` executable or isn't the `RhumbSolve` executable, see property `rhumb.RhumbSolve`. `TypeError` - Invalid `rhumb`. Overrides: object.__init__

### Position (self, s12, **unused) |
Find the position on the line given `s12`. Arguments: `s12` - Distance from the first point to the second (`meter`). Returns: A GDict with 7 items `lat1, lon1, lat2, lon2, azi12, s12, S12`.

### toStr (self, **prec_sep_other) |
Return this `RhumbLineSolve` as string. Arguments: `prec_sep` - See toStr. Returns: RhumbLineSolve items (`str`). Overrides: named._Named.toStr

Property Details

### azi12 Get this rhumb line's azimuth (compass `degrees`). Get method: azi12(self) - Get this rhumb line's azimuth (compass `degrees`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### azi1 Get this rhumb line's azimuth (compass `degrees`). Get method: azi12(self) - Get this rhumb line's azimuth (compass `degrees`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### azi12_sincos2 Get the sine and cosine of this rhumb line's azimuth (2-tuple `(sin, cos)`). Get method: azi12_sincos2(self) - Get the sine and cosine of this rhumb line's azimuth (2-tuple `(sin, cos)`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### azi1_sincos2 Get the sine and cosine of this rhumb line's azimuth (2-tuple `(sin, cos)`). Get method: azi12_sincos2(self) - Get the sine and cosine of this rhumb line's azimuth (2-tuple `(sin, cos)`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.